@@ -199,8 +199,35 @@ def operator_check(left_argument, right_argument, show_failed=False, print_width
         return returned_dictionary
 
 
-def argument_inspector(arg, no_of_arguments, p=False, print_width=120):
+extended_builtins = ['Ellipsis', 'False', 'None', 'NotImplemented', 'True', 'abs', 'all', 'any',
+                     'ascii', 'bin', 'bool', 'bytearray', 'bytes', 'callable', 'chr',
+                     'classmethod', 'compile', 'complex', 'delattr', 'dict',
+                     'dir', 'divmod', 'enumerate', 'eval', 'exec',
+                     'filter', 'float', 'frozenset', 'getattr', 'globals', 'hasattr',
+                     'hash', 'hex', 'id', 'int', 'isinstance', 'issubclass',
+                     'iter', 'len', 'list', 'locals', 'map', 'max', 'memoryview', 'min',
+                     'next', 'object', 'oct', 'ord', 'pow', 'property', 'range',
+                     'repr', 'reversed', 'round', 'set', 'setattr', 'slice', 'sorted',
+                     'staticmethod', 'str', 'sum', 'super', 'tuple', 'type', 'vars', 'zip',
+                     "(iter(b''))", '(iter(bytearray()))', '(iter({}.keys()))',
+                     '(iter({}.values()))', '(iter({}.items()))', '(iter([]))',
+                     '(iter(reversed([])))', '(iter(range(0)))', '(iter(set()))', "(iter(''))",
+                     '(iter(()))', '(iter(zip()))', '(lambda x: 1).__code__.co_lines',
+                     '(lambda x: 1).__code__.co_positions', '(type.__dict__)',
+                     '((lambda: (yield))())', 'dict().keys', 'dict().values', 'dict().items']
+
+external_checks = {'imports': 'from collections import Counter, namedtuple, defaultdict, OrderedDict;\
+                               from types import SimpleNamespace;\
+                               from fractions import Fraction;\
+                               from decimal import Decimal;',
+                   'modules': ['Counter', 'Fraction', 'Decimal', 'defaultdict', 'OrderedDict', 'namedtuple',
+                               'SimpleNamespace']}
+
+
+def argument_inspector(arg, no_of_arguments=2, p=False, print_width=120):
     from collections import defaultdict
+    import warnings
+    warnings.filterwarnings("ignore")
     rtrnd_dct = defaultdict(set)
     if no_of_arguments >= 0:
         try:
@@ -220,7 +247,7 @@ def argument_inspector(arg, no_of_arguments, p=False, print_width=120):
 
             try:
                 x = eval(f'{arg}({i}())')
-                rtrnd_dct[1].add(i)
+                rtrnd_dct[1].add(f'{i}()')
             except:
                 pass
 
@@ -334,30 +361,6 @@ def argument_inspector(arg, no_of_arguments, p=False, print_width=120):
         return rtrnd_dct
 
 
-extended_builtins = ['Ellipsis', 'False', 'None', 'NotImplemented', 'True', 'abs', 'all', 'any',
-                     'ascii', 'bin', 'bool', 'bytearray', 'bytes', 'callable', 'chr',
-                     'classmethod', 'compile', 'complex', 'delattr', 'dict',
-                     'dir', 'divmod', 'enumerate', 'eval', 'exec',
-                     'filter', 'float', 'frozenset', 'getattr', 'globals', 'hasattr',
-                     'hash', 'hex', 'id', 'int', 'isinstance', 'issubclass',
-                     'iter', 'len', 'list', 'locals', 'map', 'max', 'memoryview', 'min',
-                     'next', 'object', 'oct', 'ord', 'pow', 'property', 'range',
-                     'repr', 'reversed', 'round', 'set', 'setattr', 'slice', 'sorted',
-                     'staticmethod', 'str', 'sum', 'super', 'tuple', 'type', 'vars', 'zip',
-                     "(iter(b''))", '(iter(bytearray()))', '(iter({}.keys()))',
-                     '(iter({}.values()))', '(iter({}.items()))', '(iter([]))',
-                     '(iter(reversed([])))', '(iter(range(0)))', '(iter(set()))', "(iter(''))",
-                     '(iter(()))', '(iter(zip()))', '(lambda x: 1).__code__.co_lines',
-                     '(lambda x: 1).__code__.co_positions', '(type.__dict__)',
-                     '((lambda: (yield))())', 'dict().keys', 'dict().values', 'dict().items']
-
-external_checks = {'imports': 'from collections import Counter, namedtuple, defaultdict, OrderedDict;\
-                               from types import SimpleNamespace;\
-                               from fractions import Fraction;\
-                               from decimal import Decimal;',
-                   'modules': ['Counter', 'Fraction', 'Decimal', 'defaultdict', 'OrderedDict', 'namedtuple',
-                               'SimpleNamespace']}
-
 inspection_arguments = [1, 1.2, 'abc', '1', '1.2', '1/2', {1, 2, 3}, {'a': 1, 'b': 2}, (1, 2, 3), [1, 2, 3],
                         {'a', 'b', 'c'}, ('a', 'b', 'c'), ['a', 'b', 'c'], 1 + 2j, b'2', b'a', bytearray(1),
                         frozenset({1, 2, 3}), frozenset({'a', 'b', 'c'})]
